==> beagle-0.0.12.tar.bz2: beagle-0.0.12/beagled/Lucene.Net/Search/HitCollector.cs <==
/*
 * Copyright 2004 The Apache Software Foundation
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
namespace Lucene.Net.Search
{
	/// <summary>Lower-level search API.</summary>
	/// <seealso cref="Searcher#Search(Query,HitCollector)">
	/// </seealso>
	/// <version>  $Id: HitCollector.cs,v 1.2 2005/01/17 19:54:30 joeshaw Exp $
	/// </version>
	public abstract class HitCollector
	{
		/// <summary>Called once for every non-zero scoring document, with the document number
		/// and its score.
		/// 
		/// <P>If, for example, an application wished to collect all of the hits for a
		/// query in a BitSet, then it might:<pre>
		/// Searcher searcher = new IndexSearcher(indexReader);
		/// final BitSet bits = new BitSet(indexReader.maxDoc());
		/// searcher.search(query, new HitCollector() {
		/// public void collect(int doc, float score) {
		/// bits.set(doc);
		/// }
		/// });
		/// </pre>
		/// 
		/// <p>Note: This is called in an inner search loop.  For good search
		/// performance, implementations of this method should not call
		/// {@link Searcher#Doc(int)} or
		/// {@link Lucene.Net.Index.IndexReader#Document(int)} on every
		/// document number encountered.  Doing so can slow searches by an order
		/// of magnitude or more.
		/// <p>Note: The <code>score</code> passed to this method is a raw score.
		/// In other words, the score will not necessarily be a float whose value is
		/// between 0 and 1.
		/// </summary>
		public abstract void  Collect(int doc, float score);
	}
}

==> beagle-0.1.3.tar.bz2: beagle-0.1.3/beagled/Lucene.Net/Search/HitCollector.cs <==
/*
 * Copyright 2004 The Apache Software Foundation
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
using System;
namespace Lucene.Net.Search
{
    /// <summary>Lower-level search API.
    /// <br>HitCollectors are primarily meant to be used to implement queries,
    /// sorting and filtering.
    /// </summary>
    /// <seealso cref="Searcher#Search(Query,HitCollector)">
    /// </seealso>
    /// <version>  $Id: HitCollector.cs,v 1.3 2005/10/06 19:29:57 dsd Exp $
    /// </version>
    public abstract class HitCollector
	{
		/// <summary>Called once for every non-zero scoring document, with the document number
		/// and its score.
		/// 
		/// <P>If, for example, an application wished to collect all of the hits for a
		/// query in a BitSet, then it might:<pre>
		/// Searcher searcher = new IndexSearcher(indexReader);
		/// final BitSet bits = new BitSet(indexReader.maxDoc());
		/// searcher.search(query, new HitCollector() {
		/// public void collect(int doc, float score) {
		/// bits.set(doc);
		/// }
		/// });
		/// </pre>
		/// 
		/// <p>Note: This is called in an inner search loop.  For good search
		/// performance, implementations of this method should not call
		/// {@link Searcher#Doc(int)} or
		/// {@link Lucene.Net.Index.IndexReader#Document(int)} on every
		/// document number encountered.  Doing so can slow searches by an order
		/// of magnitude or more.
		/// <p>Note: The <code>score</code> passed to this method is a raw score.
		/// In other words, the score will not necessarily be a float whose value is
		/// between 0 and 1.
		/// </summary>
		public abstract void  Collect(int doc, float score);
	}
}
